#!/bin/bash

cd $(dirname $0)
SCRIPTDIR=$(pwd)
echo $SCRIPTDIR

export PATH="$PATH:$SCRIPTDIR/bin"
export LD_LIBRARY_PATH="$SCRIPTDIR/lib"

. defines


#check browser.done file
if [ ! -f browser.done -a -f browser.ini ]; then
    echo -e "var browser_settings =" `sed -f ini2json.sed browser.ini` > ext/config/browser_settings.js
    DEF_USER_AGENT="$( cat browser.ini | grep customUserAgent | sed 's/^;.*//' | cut -d'=' -f2 | tail -n1 )"
    touch browser.done
else
   echo "var browser_settings = {}" > "ext/config/browser_settings.js"
fi

if !( df -h $CACHE_DIR 2>/dev/null | sed -n 2p | grep -q ^tmpfs ); then
	mkdir -p $CACHE_DIR
	if [ -x /usr/bin/mount_tmpfs ]; then
		mount_tmpfs $CACHE_DIR $(( $CACHE_SIZE_MB +3 ))
	else
		mount -t tmpfs -o size=$(( $CACHE_SIZE_MB +3 ))M tmpfs $CACHE_DIR
	fi
fi

if [ -n "$WAYLAND" ]; then
	GPU_FLAGS="--use-gl=egl --ozone-platform=wayland --in-process-gpu --disable-gpu-rasterization"
elif ( echo $CPU | grep -q "Freescale i.MX6" ) && ( lsmod | grep -q galcore ); then
	GPU_FLAGS="--use-gl=egl --enable-zero-copy --enable-accelerated-2d-canvas \
                --enable-gpu-compositing --enable-threaded-compositing  --gpu-no-context-lost \
                --enable-gpu-memory-buffer-video-frames --enable-native-gpu-memory-buffers"
else
	GPU_FLAGS="--disable-gpu"
fi

[ -e $CHROME_WINDOW_FLAG ] && exit 0
touch $CHROME_WINDOW_FLAG


disabledFeatures="TranslateUI"
if [ "${extDB[overscrollHistoryNavigation]}" = "false" ]; then
	disabledFeatures="$disabledFeatures,OverscrollHistoryNavigation"
fi

CHROME_ARGS="--no-sandbox --extensions-on-chrome-urls --disable-session-crashed-bubble --disable-features=$disabledFeatures \
        --disable-infobars --no-first-run --kiosk --disable-component-update --disable-sync \
        --user-data-dir=$DATA_DIR --disk-cache-size=$(( $CACHE_SIZE_MB *1024 *1024 )) $GPU_FLAGS"

[ -n "$WAYLAND" ] && CHROME_ARGS="$CHROME_ARGS --enable-wayland-ime"

# Uncomment to enable verbose log
# CHROME_ARGS="$CHROME_ARGS --enable-logging=stderr --v=1"

# Uncomment to enable remote debugging on port 9222
# CHROME_ARGS="$CHROME_ARGS --remote-debugging-port=9222"

# Uncomment and set <IP> and <PORT> to enable proxy
# CHROME_ARGS="$CHROME_ARGS --proxy-bypass-list=127.0.0.1 --proxy-server=<IP>:<PORT>"

if [ -z "$WAYLAND" ]; then
	# Non multitouch devices are not recognized as touchscreens. We need to force chromium to believe they are
	titscdev=$( /usr/bin/xinput | grep ti-tsc | sed "s:.*id=\([0-9]*\).*:\1:" )
	[ -n "$titscdev" ] && CHROME_ARGS="$CHROME_ARGS --touch-devices=$titscdev --touch-events"
	tsc200xdev=$( /usr/bin/xinput | grep 'TSC200\(4\|X\)' | sed "s:.*id=\([0-9]*\).*:\1:" )
	[ -n "$tsc200xdev" ] && CHROME_ARGS="$CHROME_ARGS --touch-devices=$tsc200xdev --touch-events"
fi

CHROME_ARGS_BG="$CHROME_ARGS --load-extension=$EXTENSION_DIR --no-startup-window"

[ -n "${extDB[customUserAgent]}" ] && USER_AGENT="--user-agent=${extDB[customUserAgent]}"
[ -n "$DEF_USER_AGENT" ] && USER_AGENT="--user-agent=$DEF_USER_AGENT"

# Clean metrics folder if found
[ -e $DATA_DIR/BrowserMetrics ] && rm -r $DATA_DIR/BrowserMetrics

if [ -e $DATA_DIR/Default/Preferences ]; then
	# Make sure the extension is not disabled
	if [ $(getPreference ".extensions.settings.$EXTENSION_ID.state") = "0" ]; then
		setPreference ".extensions.settings.$EXTENSION_ID.state" "1"
	fi

	if [ "${extDB[clearCertificateDecisions]}" = "true" ]; then
		setPreference ".profile.content_settings.exceptions.ssl_cert_decisions" "{}"
	fi

	zoomValue="$(zoomToValue ${extDB[zoom]})"
	if [ -n "$zoomValue" -a "$(getPreference .partition.default_zoom_level.x)" != "$zoomValue" ]; then
		setPreference .partition.default_zoom_level.x $zoomValue
	fi
fi

sync_pw_db

sleep 2

( pidof chromium-bin &>/dev/null ) && daemonRunning=1

if [ ! -n "$daemonRunning" ]; then
	rm -rf $DATA_DIR/Singleton*
	rm -f "$EXTENSION_CACHE_LOCK"
fi

ulimit -c unlimited

(
	export GTK_IM_MODULE_FILE=

	# Wait for daemon socket and extension cache dir to be created
	while [ ! -e $DATA_DIR/SingletonSocket -o ! -e "$EXTENSION_CACHE_LOCK" ]; do
		sleep 1
	done;

	dbus-send --print-reply --system --dest=com.exor.JMLauncher '/' com.exor.JMLauncher.appLoaded string:"Chromium"

	# Open a browser window
	./chromium-bin $CHROME_ARGS $@

	rm -f $CHROME_WINDOW_FLAG
) &

if [ -n "$daemonRunning" ]; then
	echo Daemon already running
	sleep 10
	exit 0
fi

# Pass command line to extension
[ -e settings ] && CMD_LINE="$( cat settings )"
CMD_LINE="$CMD_LINE $@"
echo 'var cmd_line = "'$CMD_LINE'";' > $EXTENSION_CMD_FILE
echo 'var inst_dir = "'$SCRIPTDIR'";' >> $EXTENSION_CMD_FILE

# Run the daemon fist to make sure the extension is loaded
./chromium-bin $CHROME_ARGS_BG "$USER_AGENT"

if [ $? -eq "137" -a ! -e $DATA_DIR/SingletonSocket ]; then
	sleep 2
	./chromium-bin $CHROME_ARGS_BG "$USER_AGENT"
fi

rm -f $CHROME_WINDOW_FLAG

if ls core* &> /dev/null ; then

	xsplash --no-taptap --no-progress-bar &
	sleep 2

	psplash-write "MSG The browser exited unexpectedly
Please wait..."

	# Keep a maximum of 5 core dump reports
	if [ -d crash_dumps -a "$( ls crash_dumps 2>/dev/null | wc -l )" -gt "4" ]; then
		rm -rf "crash_dumps/$( ls crash_dumps | head -n1 )"
	fi

	CRASHLOGNAME="$(date +%Y%m%d%H%M%S)-crashlog"
	mkdir -p crash_dumps/${CRASHLOGNAME}
	mv core crash_dumps/${CRASHLOGNAME}
	cp ../package.info crash_dumps/${CRASHLOGNAME}
	cp /boot/version crash_dumps/${CRASHLOGNAME}
	cp -Lr /var/log crash_dumps/${CRASHLOGNAME}
	sync

	tar czvf crash_dumps/${CRASHLOGNAME}.tar.gz -C crash_dumps ${CRASHLOGNAME} &>/dev/null
	rm -r crash_dumps/${CRASHLOGNAME}
	sync

	psplash-write "QUIT"
fi
